Struct fmc_protocol::messages::Chunk
source · pub struct Chunk {
pub position: IVec3,
pub blocks: Vec<u16>,
pub block_state: HashMap<usize, u16>,
}Expand description
A chunk of blocks sent to a client
Fields
position: IVec3The position the chunk takes in the block grid.
blocks: Vec<u16>The blocks the chunk consists of.
block_state: HashMap<usize, u16>Trait Implementations
sourceimpl ClientBound for Chunk
impl ClientBound for Chunk
const TYPE: MessageType = crate::MessageType::Chunk
sourceimpl Component for Chunk
impl Component for Chunk
sourceconst STORAGE_TYPE: StorageType = bevy::ecs::component::StorageType::SparseSet
const STORAGE_TYPE: StorageType = bevy::ecs::component::StorageType::SparseSet
A constant indicating the storage type used for this component.
sourcefn register_component_hooks(_hooks: &mut ComponentHooks)
fn register_component_hooks(_hooks: &mut ComponentHooks)
Called when registering this component, allowing mutable access to its
ComponentHooks.sourceimpl<'de> Deserialize<'de> for Chunk
impl<'de> Deserialize<'de> for Chunk
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Event for Chunk